@@ -1,7 +1,6 @@
+from odd_models.discovery.data_assets.data_asset import DataAsset
 from odd_models.models import DataEntity
 
-from .data_asset import DataAsset
-
 
 class Database(DataAsset):
     def __init__(self, oddrn: str) -> None:
